@@ -13,13 +13,97 @@ for my $cat ( qw( Chunked Compressed Clen Broken Mime MessageRfc822 Range ) ) {
 
 sub categories { @cat }
 sub make_response {
-    my $page = "<!doctype html><html><body>";
-    $page .= "<a href=/auto/all/novirus.txt>Bulk test browser/proxy behavior</a><br>\n";
-    $page .= "<a href=/auto/all/eicar.txt>Bulk test firewall evasion with EICAR test virus</a><br>\n";
-    $page .= "<hr>\n";
+    my $page = <<'HTML';
+<!doctype html><html><body>
+<link rel="stylesheet" href="/stylesheet.css">
+<h1>HTTP standard conformance tests - HTTP evader</h1>
+
+<p>
+While HTTP seems to be a simple protocol it is in reality complex enough that
+different implementations of the protocol vary how the behave in case of HTTP
+responses which are either slightly invalid or valid but uncommon.
+These interpretation differences is critical if a firewall behaves
+differently then the browser it should protect because it can be abused to
+bypass the protection of the firewall.
+</p>
+
+<p>
+The following tests are intended to test the behavior of browsers regarding
+invalid or uncommon HTTP responses. And if there is a firewall or proxy between
+the test server and the browser then it can be seen how this affects the results
+and if a bypass of the protection would be possible.
+More information about bypassing firewalls using interpretation differences can
+be found <a href=http://noxxi.de/research/semantic-gap.html>here</a>.
+</p>
+
+<h2>Bulk test with innocent payload</h2>
+
+<p>
+This bulk test automatically triggers various kinds of strange HTTP responses
+which contain an innocent payload and compares the payload it gets in the
+browser against the expected payload. It uses XMLHttpRequests for this purpose
+which often but not in all cases show the same behavior as other HTTP requests
+by the browser (i.e. loading image, script,...). 
+In lots of cases the browser will extract the original payload from the response
+even the response itself was invalid. On the other hand there are cases were the
+browser does not get the expected payload even if the response was valid,
+because either the browser or a proxy/firewall in between does not fully
+understand legit HTTP or blocked legit but uncommon HTTP for security reasons.
+</p>
+<p class=runtest><a href=/auto/all/novirus.txt>Run Test</a></p>
+
+<h2>Bulk test with virus payload</h2>
+
+<p>
+This is the same bulk test as the previous test with the exception that the
+payload is a virus this time. The payload consists of the <a
+href=http://www.eicar.org/86-0-Intended-use.html>EICAR test virus</a> which is
+commonly used for basic tests of antivirus and which should be detected by every
+firewall which does deep inspection to filter out malware. 
+</p>
+<p>
+The goal of this test is to find out if the firewall interprets the HTTP
+response in a different way then the browser and if this would allow a critical
+bypass of the firewalls protection. Since the EICAR test virus used in this test
+is not malicious it is safe to run this test even if the firewall gets
+successfully bypassed.
+It is important to consider that the XMLHttpRequests used for this tests do 
+behave the same as normal download links in most but not all cases. This means
+to verify that an evasion is actually possible with a download link one should
+use the provided link to actually test the evasion.
+</p>
+<p class=runtest><a href=/auto/all/eicar.txt>Run Test</a></p>
+
+<h2>Non-Bulk tests</h2>
+
+<p>
+The following tests analyze the behavior of browsers in specific cases, like
+loading an image, loading a script and loading HTML into an iframe. They offer a
+download for the EICAR test virus. The subtests in these tests all follow the
+same style: If the browser behaves like expected (i.e. fails or succeeds) the
+relevant element (IMAGE, SCRIPT or HTML) will turn green, if it behaves
+differently it will turn red. Yellow is similar successful as green but marks an
+uncommon behavior. If this uncommon behavior is not implemented (i.e. load of
+image or script failed) the element will be grey. 
+When trying to load HTML into an iframe it can happen that the iframe stays
+empty or contains some error message or garbage instead of "HTML". In this case
+it failed to load the content.
+</p>
+<p>
+Which behavior is expected can be seen from the header preceding
+the relevant section of subtests: if it says that the following requests are
+VALID it is expected that loading succeeds, on INVALID requests it is expected
+that they fail. In other words: anything turning red is bad and more so if it is
+for INVALID requests. Because in this case the browser executes the payload even
+if the HTTP response was invalid which might often be used to bypass firewalls
+which behave differently.
+</p>
+
+HTML
     for( grep { $_->TESTS } @cat ) {
-	$page .= "<a href=/".$_->ID.">".html_escape($_->SHORT_DESC)."</a>\n";
-	$page .= "<pre>".html_escape( $_->LONG_DESC )."</pre>";
+	$page .= "<h3>".html_escape($_->SHORT_DESC)."</h3>";
+	$page .= $_->LONG_DESC_HTML;
+	$page .= "<p class=runtest><a href=/".$_->ID.">Run Test</a></p>\n";
     }
     $page .= "</body></html>";
     return "HTTP/1.0 200 ok\r\n".
