@@ -62,34 +62,34 @@ IMAGE
     'ok.html' =>  sub {
 	my $spec = shift;
 	return [ "Content-type: text/html\r\n", 
-	    "<body>ok<script src=/ping.js></script><script>ping_back('/ping?OK:$spec')</script></body>" ]
+	    "<script src=/ping.js></script><script>ping_back('/ping?OK:$spec')</script><body style='background: #00e800;'><div style='text-align:center'>HTML</div></body>" ]
     },
     'bad.html' =>  sub {
 	my $spec = shift;
 	return [ "Content-type: text/html\r\n", 
-	    "<body>BAD!<script src=/ping.js></script><script>ping_back('/ping?BAD:$spec')</script></body>" ]
+	    "<script src=/ping.js></script><script>ping_back('/ping?BAD:$spec')</script><body style='background: #e30e2c;'><div style='text-align:center'>HTML</div></body>" ]
     },
     'warn.html' =>  sub {
 	my $spec = shift;
 	return [ "Content-type: text/html\r\n", 
-	    "<body>EEEK!<script src=/ping.js></script><script>ping_back('/ping?WARN:$spec')</script></body>" ]
+	    "<script src=/ping.js></script><script>ping_back('/ping?WARN:$spec')</script><body style='background: #e7d82b'><div style='text-align:center'>HTML</div></body>" ]
     },
 
     # we hide javascript behind GIF87a to work around content filters :)
     'ok.js' => sub {
 	my $spec = shift;
 	return [ "Content-type: application/javascript\n",
-	    "GIF87a=1;ping_back('/ping?OK:$spec');" ]
+	    "GIF87a=1;try { document.getElementById('$spec').style.backgroundColor = '#00e800'; } catch(e) {} ping_back('/ping?OK:$spec');" ]
     },
     'bad.js' => sub {
 	my $spec = shift;
 	return [ "Content-type: application/javascript\r\n",
-	    "GIF87a=1;ping_back('/ping?BAD:$spec');" ]
+	    "GIF87a=1;try { document.getElementById('$spec').style.backgroundColor = '#e30e2c'; } catch(e) {} ping_back('/ping?BAD:$spec');" ]
     },
     'warn.js' => sub {
 	my $spec = shift;
 	return [ "Content-type: application/javascript\r\n",
-	    "GIF87a=1;ping_back('/ping?WARN:$spec');" ]
+	    "GIF87a=1;try { document.getElementById('$spec').style.backgroundColor = '#e7d82b'; } catch(e) {} ping_back('/ping?WARN:$spec');" ]
     },
     'ping' =>  [ "Content-type: text/plain\r\n", "pong" ],
     'ping.js' => [ 
@@ -113,6 +113,45 @@ function ping_back(url) {
     }
 }
 PING_JS
+    'stylesheet.css' => [
+	"Content-type: text/css\r\n".
+	"Expires: Tue, 30 Jul 2033 20:04:02 GMT\r\n",
+	<<'STYLESHEET' ],
+body { max-width: 55em; line-height: 140%; margin-left: 2em; }
+ul { list-style-type: square; padding-left: 2em; }
+h1 { font-variant: small-caps; font-size: x-large; }
+h2,h3 { font-size: large; }
+.runtest { text-align: right; margin-right: 20%; }
+.runtest a {
+  text-decoration: none;
+  background-color: #a3a9d4;
+  color: #333333;
+  padding: 4px 6px 4px 6px;
+  white-space: nowrap;
+}
+
+h1,h2,h3 { border: 1px; border-style: solid; padding: 5px 10px 5px 10px; }
+h1 { color: #000; background: #eee; padding-top: 10px; padding-bottom: 10px; }
+h2 { color: #444; background: #eee; }
+h3 { color: #444; background: #fff; }
+h2,h3 { margin-top: 2em; }
+
+* { font-size: medium; font-family: Verdana,sans-serif; }
+
+pre { font-family: Monospace,monospace; }
+
+.button {
+  text-decoration: none;
+  background-color: #EEEEEE;
+  color: #333333;
+  padding: 2px 6px 2px 6px;
+  border-top: 1px solid #CCCCCC;
+  border-right: 1px solid #333333;
+  border-bottom: 1px solid #333333;
+  border-left: 1px solid #CCCCCC;
+  white-space: nowrap;
+}
+STYLESHEET
 );
 
 
@@ -160,7 +199,7 @@ sub SETUP {
     no strict 'refs';
     *{$pkg.'::ID'} = sub { $id };
     *{$pkg.'::SHORT_DESC'} = sub { $desc };
-    *{$pkg.'::LONG_DESC'} = sub { $ldesc };
+    *{$pkg.'::LONG_DESC_HTML'} = sub { $ldesc };
     *{$pkg.'::TESTS'} = sub { @tests_only };
     *{$pkg.'::make_index_page'} = sub { make_index_page($pkg,@tests) };
 
@@ -181,38 +220,30 @@ sub make_index_page {
     my $class = shift;
     my $body = <<'BODY';
 <!doctype html><html lang=en><body>
-<style>
-.button {
-  text-decoration: none;
-  background-color: #EEEEEE;
-  color: #333333;
-  padding: 2px 6px 2px 6px;
-  border-top: 1px solid #CCCCCC;
-  border-right: 1px solid #333333;
-  border-bottom: 1px solid #333333;
-  border-left: 1px solid #CCCCCC;
-}
-</style>
 <script src=/ping.js></script>
+<link rel="stylesheet" href="/stylesheet.css">
 BODY
-    $body .= "<pre>".html_escape($class->LONG_DESC())."</pre><hr>";
-    $body .= "<table>";
+    $body .= "<h1>".$class->SHORT_DESC."</h1>";
+    $body .= $class->LONG_DESC_HTML()."<hr>";
+    $body .= '<table style="width: 100%; border-style: none; border-spacing: 0px;">';
     for my $test (@_) {
 	if (!blessed($test)) {
-	    $body .= "<tr><td colspan=3><hr>$test->[0]<hr></td></tr>";
+	    $body .= "<tr><td colspan=5><h2>$test->[0]</h2></td></tr>";
 	    next;
 	} 
 	my $valid = $test->VALID;
 	my $base = $valid>0 ? 'ok' : $valid<0 ? 'warn' : 'bad';
-	my $bg   = $valid>0 ? '#e30e2c' : $valid<0 ? '#d0cfd1' : '#00e800';
+	my $bg = $valid>0 ? '#e30e2c' : $valid<0 ? '#d0cfd1' : '#00e800';
 	$body .= "<tr>";
-	$body .= "<td style='border-style:none; background: $bg url(\"".$test->url("$base.png"). "\");'>&nbsp;". 
-	    html_escape($test->DESCRIPTION) ."&nbsp;&nbsp;</td>";
-	$body .= "<td style='border-style:none;'><iframe seamless=seamless scrolling=no style='width: 8em; height: 2em; overflow: hidden;' src=". $test->url("$base.html"). "></iframe></td>";
-	$body .= "<td>&nbsp;<a class=button href=". $test->url('eicar.txt').">load EICAR</a>&nbsp;</td>";
-	# $body .= "<td>&nbsp;<a class=button href=". $test->url('eicar-gz-zip.zip').">load gzjunk+eicar.zip</a>&nbsp;</td>";
+	$body .= "<td>". html_escape($test->DESCRIPTION) ."</td>";
+	$body .= "<td><div style='height: 2em; border-style: solid; border-width: 1px; width: 6em; text-align: center; background: $bg url(\"".$test->url("$base.png"). "\");'><span style='vertical-align: middle;'>IMAGE</span></div></td>";
+	$body .= "<td><div id='".$test->ID."' style='height: 2em; border-style: solid; border-width: 1px; width: 6em; text-align: center; background: $bg'><span style='vertical-align: middle;'>SCRIPT</span></div></td>";
+	$body .= "<td><iframe seamless=seamless scrolling=no style='border-style: solid; border-width: 1px; width: 6em; height: 2em; overflow: hidden;' src=". $test->url("$base.html"). "></iframe></td>";
+	$body .= "<td>&nbsp;<a class=button target=_blank href=". $test->url('eicar.txt').">load EICAR</a>&nbsp;</td>";
+	# $body .= "<td>&nbsp;<a class=button target=_blank href=". $test->url('eicar-gz-zip.zip').">load gzjunk+eicar.zip</a>&nbsp;</td>";
 	$body .= "</tr>";
 	$body .= "<script src=".$test->url("$base.js")."></script>";
+	$body .= "<tr><td colspan=5><hr></td></tr>";
     }
     $body .= "</table>";
     $body .= "</body></html>";
