@@ -7,14 +7,17 @@ SETUP(
     'range',
     "unexpected range header",
     <<'DESC',
-Try to trick browsers into accepting partial data (and requesting rest)
+These tests try to trick browsers into accepting partial data (and requesting rest)
 by using Range headers in response, even if no range was requested.
 It seems, that this does not work - but at least wget tries to automatically
 resume a broken request with a partial request.
 DESC
 
     # ---------------- Tests ----------------------------------------
+    [ "VALID: all data at once" ],
     [ VALID, 'full' => 'all data at once' ],
+
+    [ "INVALID: range without requested" ],
     [ INVALID, 'range',"send partial response even if full was requested" ],
     [ INVALID, 'range,incomplete',"use incomplete response to trigger partial request for rest of data" ],
 );
